<template>
  <el-bus-crud v-bind="tableConfig"></el-bus-crud>
</template>

<script>
import { dateRangeOptions } from '@/utils/options'
import CustomDateRange from '@/components/custom-date-range.vue'
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/order/list',
        hasNew: false,
        hasEdit: false,
        hasDelete: false,
        onResetView: (row) => {
          this.$router.push(`/order/list/${row.id}`)
        },
        extraQuery: {
          billId: this.$route.params.id,
        },
        columns: [
          { label: '序号', type: 'index' },
          { label: '订单号', prop: 'orderNo' },
          { label: '收货人', prop: 'customer' },
          { label: '花款(售价)', prop: 'totalAmount' },
          { label: '花款(底价)', prop: 'supplierAmount' },
        ],
        searchFormAttrs: {
          labelWidth: 'auto',
        },
        searchForm: [
          {
            type: 'row',
            span: 6,
            items: [
              {
                label: '下单日期：',
                id: 'dateType',
                component: CustomDateRange,
                el: {
                  options: dateRangeOptions,
                },
                searchImmediately: true,
                commonFormat: true,
                commonFormatProps: [
                  'dateType',
                  'createStartDateStr',
                  'createEndDateStr',
                ],
                span: 24,
              },
              { label: '订单号：', id: 'orderNo', type: 'input' },
              { label: '商品名称：', id: 'flowerName', type: 'input' },
              {
                label: '收货人：',
                id: 'customer',
                type: 'input',
                el: { placeholder: '收货人姓名/手机号' },
              },
            ],
          },
        ],
      },
    }
  },
  head() {
    return {
      title: this.isPartner ? '合伙人账单结算明细' : '普通账单结算明细',
    }
  },
  computed: {
    isPartner() {
      return this.$route.params.type === 'partner'
    },
  },
}
</script>
